@@ -17,6 +17,9 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 请求头中的 Uin 无效
+AUTHFAILURE_INVALIDHEADERUIN = 'AuthFailure.InvalidHeaderUin'
+
 # 该地域尚未开放，请选择其他地域。
 AUTHFAILURE_INVALIDREGION = 'AuthFailure.InvalidRegion'
 
@@ -47,6 +50,9 @@ FAILEDOPERATION_DESCRIBEBUNDLEDISCOUNTFAILED = 'FailedOperation.DescribeBundleDi
 # 查询套餐失败
 FAILEDOPERATION_DESCRIBEBUNDLESFAILED = 'FailedOperation.DescribeBundlesFailed'
 
+# 查询云硬盘是否可以退还操作失败。
+FAILEDOPERATION_DESCRIBEDISKSRETURNABLEERROR = 'FailedOperation.DescribeDisksReturnableError'
+
 # 查询实例状态错误。
 FAILEDOPERATION_DESCRIBEINSTANCESTATUS = 'FailedOperation.DescribeInstanceStatus'
 
@@ -131,9 +137,6 @@ FAILEDOPERATION_UNABLETOCREATEINSTANCES = 'FailedOperation.UnableToCreateInstanc
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
-# 查询磁盘返回了不合法内容。
-INTERNALERROR_DESCRIBEDISKSRETURNABLEERROR = 'InternalError.DescribeDisksReturnableError'
-
 # 查询实例状态失败，请稍后重试。
 INTERNALERROR_DESCRIBEINSTANCESTATUS = 'InternalError.DescribeInstanceStatus'
 
@@ -194,6 +197,12 @@ INVALIDPARAMETER_FIREWALLRULESDUPLICATED = 'InvalidParameter.FirewallRulesDuplic
 # 参数非法，防火墙规则已存在。
 INVALIDPARAMETER_FIREWALLRULESEXIST = 'InvalidParameter.FirewallRulesExist'
 
+# 游戏专区实例仅支持当前镜像。
+INVALIDPARAMETER_GAMEPORTALINSTANCEONLYSUPPORTCURRENTBLUEPRINT = 'InvalidParameter.GamePortalInstanceOnlySupportCurrentBlueprint'
+
+# 实例展示区域不支持该参数。
+INVALIDPARAMETER_INSTANCEDISPLAYAREANOTSUPPORTPARAMETER = 'InvalidParameter.InstanceDisplayAreaNotSupportParameter'
+
 # 参数非法，Filter 参数非法。
 INVALIDPARAMETER_INVALIDFILTER = 'InvalidParameter.InvalidFilter'
 
@@ -230,6 +239,9 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # 镜像不允许共享至不同站点的账号。
 INVALIDPARAMETERVALUE_ACCOUNTIDINVALIDACCOUNTAREA = 'InvalidParameterValue.AccountIdInvalidAccountArea'
 
+# 账号为当前用户。
+INVALIDPARAMETERVALUE_ACCOUNTIDSAMEWITHUIN = 'InvalidParameterValue.AccountIdSameWithUin'
+
 # 账号ID不存在。
 INVALIDPARAMETERVALUE_ACCOUNTIDSNOTEXIST = 'InvalidParameterValue.AccountIdsNotExist'
 
@@ -293,6 +305,9 @@ INVALIDPARAMETERVALUE_FIELDSCOMPARE = 'InvalidParameterValue.FieldsCompare'
 # 防火墙规则描述长度超出限制。
 INVALIDPARAMETERVALUE_FIREWALLRULEDESCRIPTIONTOOLONG = 'InvalidParameterValue.FirewallRuleDescriptionTooLong'
 
+# 防火墙模板ID格式非法。
+INVALIDPARAMETERVALUE_FIREWALLTEMPLATEIDMALFORMED = 'InvalidParameterValue.FirewallTemplateIdMalformed'
+
 # 参数值非法，实例 ID 格式非法。
 INVALIDPARAMETERVALUE_INSTANCEIDMALFORMED = 'InvalidParameterValue.InstanceIdMalformed'
 
@@ -314,6 +329,9 @@ INVALIDPARAMETERVALUE_INVALIDBLUEPRINTTYPE = 'InvalidParameterValue.InvalidBluep
 # 非法的套餐参数。
 INVALIDPARAMETERVALUE_INVALIDBUNDLE = 'InvalidParameterValue.InvalidBundle'
 
+# 套餐和镜像的组合非法。
+INVALIDPARAMETERVALUE_INVALIDBUNDLEBLUEPRINTCOMBINATION = 'InvalidParameterValue.InvalidBundleBlueprintCombination'
+
 # 控制台显示类型不合法。
 INVALIDPARAMETERVALUE_INVALIDCONSOLEDISPLAYTYPES = 'InvalidParameterValue.InvalidConsoleDisplayTypes'
 
@@ -368,6 +386,9 @@ INVALIDPARAMETERVALUE_KEYPAIRPUBLICKEYDUPLICATED = 'InvalidParameterValue.KeyPai
 # 指定的公钥格式错误。
 INVALIDPARAMETERVALUE_KEYPAIRPUBLICKEYMALFORMED = 'InvalidParameterValue.KeyPairPublicKeyMalformed'
 
+# 参数取值长度不合法。
+INVALIDPARAMETERVALUE_LENGTH = 'InvalidParameterValue.Length'
+
 # 参数值非法，参数值的数量超过最大限制。
 INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'
 
@@ -377,6 +398,9 @@ INVALIDPARAMETERVALUE_NEGATIVE = 'InvalidParameterValue.Negative'
 # 不允许改变平台类型。
 INVALIDPARAMETERVALUE_NOTALLOWTOCHANGEPLATFORMTYPE = 'InvalidParameterValue.NotAllowToChangePlatformType'
 
+# 实例套餐的套餐类型不支持表更至新套餐。
+INVALIDPARAMETERVALUE_NOTSUPPORTMODIFYINSTANCEBUNDLETYPE = 'InvalidParameterValue.NotSupportModifyInstanceBundleType'
+
 # 参数值非法，不在合法范围内。
 INVALIDPARAMETERVALUE_OUTOFRANGE = 'InvalidParameterValue.OutOfRange'
 
@@ -455,9 +479,15 @@ LIMITEXCEEDED_SNAPSHOTQUOTALIMITEXCEEDED = 'LimitExceeded.SnapshotQuotaLimitExce
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 套餐缺少参数镜像ID。
+MISSINGPARAMETER_BUNDLEMISSINGPARAMETERBLUEPRINTID = 'MissingParameter.BundleMissingParameterBlueprintId'
+
 # 必须传入参数Period或CurInstanceDeadline。
 MISSINGPARAMETER_MISSINGPARAMETERPERIODCURINSTANCEDEADLINE = 'MissingParameter.MissingParameterPeriodCurInstanceDeadline'
 
+# 指定参数`Order`时，必须传入参数 `OrderField`。
+MISSINGPARAMETER_ORDERFIELDREQUIRED = 'MissingParameter.OrderFieldRequired'
+
 # 镜像在操作中。请稍后再试。
 OPERATIONDENIED_BLUEPRINTOPERATIONINPROGRESS = 'OperationDenied.BlueprintOperationInProgress'
 
@@ -596,6 +626,9 @@ RESOURCEUNAVAILABLE_DOCKERUNAVAILABLE = 'ResourceUnavailable.DockerUnavailable'
 # 防火墙模板在使用中，不支持该操作。
 RESOURCEUNAVAILABLE_FIREWALLTEMPLATEINUSE = 'ResourceUnavailable.FirewallTemplateInUse'
 
+# 当前套餐不支持通过API购买。
+RESOURCEUNAVAILABLE_INVALIDPURCHASEREQUESTSOURCE = 'ResourceUnavailable.InvalidPurchaseRequestSource'
+
 # TAT agent不可用。
 RESOURCEUNAVAILABLE_TATAGENTUNAVAILABLE = 'ResourceUnavailable.TATAgentUnavailable'
 
@@ -659,6 +692,9 @@ UNSUPPORTEDOPERATION_BLUEPRINTLATESTOPERATIONUNFINISHED = 'UnsupportedOperation.
 # 镜像被使用中，不支持该操作。
 UNSUPPORTEDOPERATION_BLUEPRINTOCCUPIED = 'UnsupportedOperation.BlueprintOccupied'
 
+# 该镜像的镜像类型不支持该操作。
+UNSUPPORTEDOPERATION_BLUEPRINTTYPENOTSUPPORTOPERATION = 'UnsupportedOperation.BlueprintTypeNotSupportOperation'
+
 # 已经关联云联网，不支持再次关联。
 UNSUPPORTEDOPERATION_CCNALREADYATTACHED = 'UnsupportedOperation.CcnAlreadyAttached'
 
@@ -686,6 +722,9 @@ UNSUPPORTEDOPERATION_FIREWALLBUSY = 'UnsupportedOperation.FirewallBusy'
 # 指定的防火墙版本号和当前版本不一致。
 UNSUPPORTEDOPERATION_FIREWALLVERSIONMISMATCH = 'UnsupportedOperation.FirewallVersionMismatch'
 
+# 实例展示区域不支持该操作。
+UNSUPPORTEDOPERATION_INSTANCEDISPLAYAREANOTSUPPORTOPERATION = 'UnsupportedOperation.InstanceDisplayAreaNotSupportOperation'
+
 # 实例已到期，不支持该操作。
 UNSUPPORTEDOPERATION_INSTANCEEXPIRED = 'UnsupportedOperation.InstanceExpired'
 
@@ -719,6 +758,9 @@ UNSUPPORTEDOPERATION_LATESTOPERATIONUNFINISHED = 'UnsupportedOperation.LatestOpe
 # 共享镜像不支持此操作。
 UNSUPPORTEDOPERATION_NOTSUPPORTSHAREDBLUEPRINT = 'UnsupportedOperation.NotSupportSharedBlueprint'
 
+# 操作不支持自动生成密码。
+UNSUPPORTEDOPERATION_OPERATIONNOTSUPPORTAUTOGENERATEPASSWORD = 'UnsupportedOperation.OperationNotSupportAutoGeneratePassword'
+
 # 国际站不支持该操作。
 UNSUPPORTEDOPERATION_OPERATIONNOTSUPPORTEDININTLSITE = 'UnsupportedOperation.OperationNotSupportedInIntlSite'
 
